/*
 * Copyright (C) 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SRC_TRACE_PROCESSOR_READ_TRACE_INTERNAL_H_
#define SRC_TRACE_PROCESSOR_READ_TRACE_INTERNAL_H_

#include <cstdint>
#include <functional>

#include "perfetto/base/export.h"
#include "perfetto/base/status.h"

namespace perfetto::trace_processor {

class TraceProcessor;

// Reads trace without Flushing the data at the end.
base::Status PERFETTO_EXPORT_COMPONENT ReadTraceUnfinalized(
    TraceProcessor* tp,
    const char* filename,
    const std::function<void(uint64_t parsed_size)>& progress_callback = {});

}  // namespace perfetto::trace_processor

#endif  // SRC_TRACE_PROCESSOR_READ_TRACE_INTERNAL_H_
